import { world } from '@minecraft/server';

function generateHealthBar(currentHealth, maxHealth, barLength = 5) {
    const healthPercentage = currentHealth / maxHealth;
    const filledBars = Math.floor(healthPercentage * barLength); 
    const emptyBars = barLength - filledBars; 

    let colorCode;
    if (healthPercentage >= 0.7) {
        colorCode = '§a'; 
    } else if (healthPercentage >= 0.3) {
        colorCode = '§e'; 
    } else {
        colorCode = '§c'; 
    }

    const filledBar = `${colorCode}█`.repeat(filledBars); 
    const emptyBar = '§7█'.repeat(emptyBars); 

    return `${filledBar}${emptyBar}`;
}

function updateEntityNameTag(entity) {
    const healthComponent = entity.getComponent('health');
    if (!healthComponent) return;

    const currentHealth = Math.round(healthComponent.currentValue);
    const maxHealth = Math.round(healthComponent.effectiveMax);

    const healthBar = generateHealthBar(currentHealth, maxHealth);
    const healthCounter = `§4❤§l§f${currentHealth}`; 

    entity.nameTag = `${healthBar}\n${healthCounter}`;
}

world.afterEvents.entitySpawn.subscribe(event => {
    const { entity } = event;

    if (entity.typeId === 'minecraft:player') return;

    updateEntityNameTag(entity);
});

world.afterEvents.entityHealthChanged.subscribe(event => {
    const { entity } = event;

    if (entity.typeId === 'minecraft:player') return;

    updateEntityNameTag(entity);
});
